@@ -1,5 +1,5 @@
 """
- * $Id: 1.1+7 utils.py d15c914d73b4 2021-06-04 od $
+ * $Id: 1.1+9 utils.py 2b62b6eac4a1 2021-06-18 od $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -482,9 +482,13 @@ class Client(object):
                 raise Exception("Not in data: " + name)
             val = self.get_data_value(name)
             print("  --> " + name)
-            response = Client.__get0(val, conf)
-            with open(os.path.join(dir, name), 'wb') as outfile:
-                outfile.write(response.content)
+            response, http_status = Client.__get0(val, conf)
+            if http_status == 200:
+                with open(os.path.join(dir, name), 'wb') as outfile:
+                    outfile.write(response.content)
+            else:
+                raise Exception("Error downloading : " + val)
+
 
     #### pubsub related properties
 
@@ -710,6 +714,12 @@ class Client(object):
 
     #### printing support
 
+
+    def asJSON(self) -> Dict:
+        # self.metainfo[self.META_KEY_MODE] = self.META_VAL_SYNC if sync else self.META_VAL_ASYNC
+        request_json = {self.METAINFO: self.metainfo, self.PARAMETER: list(self.data.values())}
+        return request_json
+
     def get_entry_asstr(self, name) -> str:
         d = self.get_data_description(name)
         if d is not None:
